==> plumed-2.6.2.tgz: plumed-2.6.2/CHANGES/v2.6.md <==
@page CHANGES-2-6 Version 2.6
  
## Version 2.6 (Jan 27, 2020)

Changes from version 2.5 which are relevant for users:
- Changes leading to incompatible behavior:
  - PLUMED input file parsing is now case insensitive that is that all directives can be written using uppercase characters (compatible with former versions) as well as lowercase characters (not compatible) internally PLUMED still uses uppercase definitions
  - `plumed partial_tempering` now uses `gawk` instead of `awk`. You might need to install `gawk` for it to work correctly.

- Other changes:
  - Asmjit is now embedded into PLUMED. In order to enable it, it is sufficient to configure with `--enable-asmjit`. See \ref Lepton "this page".
  - Fixed grids so as to decrease memory footprint of derivatives (see \issue{465}).
  - Added option `--idlp4` to \ref driver to read DLPOLY4 HISTORY files (see \issue{478}, thanks to Alin Marin Elena).
  - Added atom selectors using mdtraj/MDAnalysis/VMD syntax, see \ref MOLINFO and \issue{448}.
  - \ref EEFSOLV is now faster in scalar and also mpi/openmp parallel
  - New shortcuts are available for selecting protein atoms: `@sidechain-#`, `@back-#`
  - VIM syntax highlight is now case insensitive. Notice that autocompletion still only works with upper case commands.

- New contributed modules:
  - A new Maze module by Jakub Rydzewski
     - \ref MAZE_LOSS
     - \ref MAZE_MEMETIC_SAMPLING
     - \ref MAZE_RANDOM_ACCELERATION_MD
     - \ref MAZE_RANDOM_WALK
     - \ref MAZE_SIMULATED_ANNEALING
     - \ref MAZE_STEERED_MD
     - \ref MAZE_OPTIMIZER_BIAS
  - A new ANN module by Wei Chen and Andrew Ferguson
     - \ref ANN

- New patches:
  - added support for AMBER PMEMD 18 (contributed by Viktor Drobot, see \issue{486}).

- Changes in the VES module
  - new \ref VES_DELTA_F bias.
  - ves_md_linearexpansion now outputs one-dimensional free energy projections of the potential energy landscape. 

- Changes in the DRR module
  - The MAXFACTOR option now is tunable for each CV in multidimensional cases.
  - Output .zcount file (the same as .czar.count) for compatibility with newer abf_integrate.
  - The citation of DRR module has been updated.

- Changes in the ISDB module
  - in \ref METAINFERENCE we removed the MC_STRIDE keyword
  - in \ref METAINFERENCE the bias value (metainference score) now includes the Jeffrey's prior (values are different, but forces are equal)
  - components were previously named using _ but now they abide to the standard is -
  - removed ADDEXP keywords for \ref JCOUPLING \ref NOE \ref PRE \ref RDC
  - \ref METAINFERENCE performs more check on the input and restart files to ensure a consistent setup
  - \ref SAXS is slightly faster and scales better, removed BESSEL options

- Python module:
  - Removed compatibility with Python 2.
  - Added capability to read and write pandas dataset from PLUMED files (see \issue{496}).

Changes from version 2.5 which are relevant for developers:
  - Components documentation is now enforced
  - `readdir_r` is deprecated and is thus not used by default (can be enabled with `./configure --enable-readdir-r`).

## Version 2.6.1 (Jul 8, 2020)

For users:
- Includes all fixes up to 2.5.5
- New patches:
  - added gromacs 2019.6 
  - added gromacs 2020.2 (experimental) 
- Fixed handling of truncated octahedron box in Amber (see \issue{584}).
  Notice that the fix is for the PMEMD pactch to be used with Amber 18.
  Amber 20 has been fixed upstream, both in PMEMD and Sander code.

For developers:
- Small fix to avoid unique global symbols (see \issue{549})

## Version 2.6.2 (Oct 26, 2020)

For users:
- Includes all fixes up to 2.5.6
- Updated patches:
  - added gromacs 2020.4 (experimental: it does not yet support modular simulator)

==> plumed-2.7.3.tgz: plumed-2.7.3/CHANGES/v2.6.md <==
@page CHANGES-2-6 Version 2.6
  
## Version 2.6 (Jan 27, 2020)

Changes from version 2.5 which are relevant for users:
- Changes leading to incompatible behavior:
  - PLUMED input file parsing is now case insensitive that is that all directives can be written using uppercase characters (compatible with former versions) as well as lowercase characters (not compatible) internally PLUMED still uses uppercase definitions
  - `plumed partial_tempering` now uses `gawk` instead of `awk`. You might need to install `gawk` for it to work correctly.

- Other changes:
  - Asmjit is now embedded into PLUMED. In order to enable it, it is sufficient to configure with `--enable-asmjit`. See \ref Lepton "this page".
  - Fixed grids so as to decrease memory footprint of derivatives (see \issue{465}).
  - Added option `--idlp4` to \ref driver to read DLPOLY4 HISTORY files (see \issue{478}, thanks to Alin Marin Elena).
  - Added atom selectors using mdtraj/MDAnalysis/VMD syntax, see \ref MOLINFO and \issue{448}.
  - \ref EEFSOLV is now faster in scalar and also mpi/openmp parallel
  - New shortcuts are available for selecting protein atoms: `@sidechain-#`, `@back-#`
  - VIM syntax highlight is now case insensitive. Notice that autocompletion still only works with upper case commands.

- New contributed modules:
  - A new Maze module by Jakub Rydzewski
     - \ref MAZE_LOSS
     - \ref MAZE_MEMETIC_SAMPLING
     - \ref MAZE_RANDOM_ACCELERATION_MD
     - \ref MAZE_RANDOM_WALK
     - \ref MAZE_SIMULATED_ANNEALING
     - \ref MAZE_STEERED_MD
     - \ref MAZE_OPTIMIZER_BIAS
  - A new ANN module by Wei Chen and Andrew Ferguson
     - \ref ANN

- New patches:
  - added support for AMBER PMEMD 18 (contributed by Viktor Drobot, see \issue{486}).

- Changes in the VES module
  - new \ref VES_DELTA_F bias.
  - ves_md_linearexpansion now outputs one-dimensional free energy projections of the potential energy landscape. 

- Changes in the DRR module
  - The MAXFACTOR option now is tunable for each CV in multidimensional cases.
  - Output .zcount file (the same as .czar.count) for compatibility with newer abf_integrate.
  - The citation of DRR module has been updated.

- Changes in the ISDB module
  - in \ref METAINFERENCE we removed the MC_STRIDE keyword
  - in \ref METAINFERENCE the bias value (metainference score) now includes the Jeffrey's prior (values are different, but forces are equal)
  - components were previously named using _ but now they abide to the standard is -
  - removed ADDEXP keywords for \ref JCOUPLING \ref NOE \ref PRE \ref RDC
  - \ref METAINFERENCE performs more check on the input and restart files to ensure a consistent setup
  - \ref SAXS is slightly faster and scales better, removed BESSEL options

- Python module:
  - Removed compatibility with Python 2.
  - Added capability to read and write pandas dataset from PLUMED files (see \issue{496}).

Changes from version 2.5 which are relevant for developers:
  - Components documentation is now enforced
  - `readdir_r` is deprecated and is thus not used by default (can be enabled with `./configure --enable-readdir-r`).

## Version 2.6.1 (Jul 8, 2020)

For users:
- Includes all fixes up to 2.5.5
- New patches:
  - added gromacs 2019.6 
  - added gromacs 2020.2 (experimental) 
- Fixed handling of truncated octahedron box in Amber (see \issue{584}).
  Notice that the fix is for the PMEMD patch to be used with Amber 18.
  Amber 20 has been fixed upstream, both in PMEMD and Sander code.

For developers:
- Small fix to avoid unique global symbols (see \issue{549})

## Version 2.6.2 (Oct 26, 2020)

For users:
- Includes all fixes up to 2.5.6
- Updated patches:
  - added gromacs 2020.4 (experimental: it does not yet support modular simulator) 

## Version 2.6.3 (Apr 16, 2021)

For users:
- Includes all fixes up to 2.5.7

## Version 2.6.4 (Jul 27, 2021)

For users:
- Fixed `plumed partial_tempering` so as to correctly process `[ pairs ]` sections.
  The incorrect script was leading to unscaled 14 interactions with Glycam force field.
  (reported by Isabell Grothaus).

For developers:
- Added integer macros `PLUMED_VERSION_MAJOR` `PLUMED_VERSION_MINOR` and `PLUMED_VERSION_PATCH` to `config/version.h`.
  Can be used to write \ref LOAD -able source code portable across multiple versions.
- Fix for compilation with GCC 11 (reported by Axel Kohlmeyer, see \issue{693}).

## Version 2.6.5 (Dec 1, 2021)

For users:
- Fixed configure problem on XL compiler (see \issue{731}).
- Fixed a bug in \ref METAINFERENCE where the score was not properly updated upon multiple MC moves in the same MD step

For developers:
- Fixed several regtests decreasing their numeric precision.
